@@ -9,5 +9,6 @@ has msg_class    => "recv";
 has msg_from     => "none";
 has ttl          => 5;
 has allow_plugin => 1;
-has [qw(msg_id group_id discuss_id sender_id receiver_id sender group discuss receiver msg_time content raw_content via)];
+has msg_time     => sub{time};
+has [qw(msg_id group_id discuss_id sender_id receiver_id sender group discuss receiver content raw_content via)];
 1;
